<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

/* Exclude category from blog */
if( ! function_exists( 'elate_vt_excludeCat' ) ) {
  function elate_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'elate_vt_excludeCat');
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function elate_pingback_header() {
  if ( is_singular() && pings_open() ) {
    echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
  }
}
add_action( 'wp_head', 'elate_pingback_header' );

/* Excerpt Length */
class ElateExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: elate_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    ElateExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'ElateExcerpt::new_length');
    ElateExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(ElateExcerpt::$types[ElateExcerpt::$length]) )
      return ElateExcerpt::$types[ElateExcerpt::$length];
    else
      return ElateExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'elate_excerpt' ) ) {
  function elate_excerpt($length = 55) {
    ElateExcerpt::length($length);
  }
}

if ( ! function_exists( 'elate_new_excerpt_more' ) ) {
  function elate_new_excerpt_more( $more ) {
    return '[...]';
  }
  add_filter('excerpt_more', 'elate_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'elate_vt_tag_cloud' ) ) {
  function elate_vt_tag_cloud($tag_string){
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'elate_vt_tag_cloud', 10, 3);
}

/* Password Form */
if( ! function_exists( 'elate_vt_password_form' ) ) {
  function elate_vt_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'elate_vt_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'elate_vt_maintenance_mode' ) ) {
  function elate_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );

    if ( ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'elate_vt_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'elate_vt_footer_widgets' ) ) {
  function elate_vt_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-lg-3 col-md-6'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {

        $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];

        $output .= '<div class="'. $widget_class .'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';

      }
    }

    return $output;

  }
}

if( ! function_exists( 'elate_vt_top_bar' ) ) {
  function elate_vt_top_bar() {

    $out     = '';

    if ( ( cs_get_option( 'top_left' ) || cs_get_option( 'top_right' ) ) ) {
      $out .= '<div class="eclt-topbar"><div class="container"><div class="row">';
      $out .= elate_vt_top_bar_modules( 'left' );
      $out .= elate_vt_top_bar_modules( 'right' );
      $out .= '</div></div></div>';
    }

    return $out;
  }
}

/* WP Link Pages */
if ( ! function_exists( 'elate_wp_link_pages' ) ) {
  function elate_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'elate' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

/* Metas */
if ( ! function_exists( 'elate_post_metas' ) ) {
  function elate_post_metas() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  ?>
  <div class="bp-top-meta">
    <?php
     if ( !in_array( 'author', $metas_hide ) ) { // Author Hide
    ?>
    <div class="bp-author">
      <?php
      printf(
        '<span><i class="fa fa-user" aria-hidden="true"></i> <a href="%1$s" rel="author">%2$s</a></span>',
        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        get_the_author()
      );
      ?>
    </div>
    <?php }

     if ( !in_array( 'date', $metas_hide ) ) { // Date Hide
    ?>
    <div class="bp-date">
      <span><i class="fa fa-clock-o" aria-hidden="true"></i><?php echo get_the_date('M d Y'); ?></span>
    </div>
    <?php } // Date Hides

    if ( !in_array( 'category', $metas_hide ) ) { // Category Hide
      if ( get_post_type() === 'post') {
        $category_list = get_the_category_list( ' ' );
        if ( $category_list ) {
          echo '<div class="bp-cat"><i class="fa fa-th" aria-hidden="true"></i>'. $category_list .' </div>';
        }
      }
    } // Category Hides

  ?>
  </div>
  <?php
  }
}

/* Author Info */
if ( ! function_exists( 'elate_author_info' ) ) {
  function elate_author_info() {

    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
      $target = 'target="_blank"';
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $target = '';
    }

    // variables
    $author_text = cs_get_option('author_text');
    $author_text = $author_text ? $author_text : esc_html__( 'Author', 'elate' );
    $author_content = get_the_author_meta( 'description' );
if ($author_content) {
?>
  <div class="bp-author-info">
    <div class="author-avatar">
      <a href="<?php echo esc_url($website_url); ?>" <?php echo esc_attr($target); ?>>
        <?php echo get_avatar( get_the_author_meta( 'ID' ), 130 ); ?>
      </a>
    </div>
    <div class="author-content">
      <div class="author-pro"><?php echo esc_attr($author_text); ?></div>
      <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo get_the_author_meta('first_name').' '.get_the_author_meta('last_name'); ?></a>
      <p><?php echo get_the_author_meta( 'description' ); ?></p>
      <section class="eclt-growth-share">
        <div class="eclt-social square">
        <?php if (get_the_author_meta( 'facebook' )): ?>
        <a href="<?php echo esc_url( get_the_author_meta( 'facebook' ) ); ?>" target="_blank" class="facebook">
          <i class="fa fa-facebook"></i>
        </a><?php endif;
        if (get_the_author_meta( 'twitter' )): ?>
        <a href="<?php echo esc_url( get_the_author_meta( 'twitter' ) ); ?>" target="_blank" class="twitter">
          <i class="fa fa-twitter"></i>
        </a><?php endif;
        if (get_the_author_meta( 'linkedin' )): ?>
        <a href="<?php echo esc_url( get_the_author_meta( 'linkedin' ) ); ?>" target="_blank" class="linkedin">
          <i class="fa fa-linkedin"></i>
        </a><?php endif; ?>
        </div>
      </section>
    </div>
  </div>
<?php
} // if $author_content
  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'elate_comment_modification' ) ) {
  function elate_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="">
    <?php endif; ?>
    <div class="comment-theme">
        <div class="comment-image">
          <?php if ( $args['avatar_size'] != 0 ) {
            echo get_avatar( $comment, 90 );
          } ?>
        </div>
    </div>
    <div class="comment-main-area">
      <div class="eclt-comments-meta">
        <h4><?php printf( '%s', get_comment_author() ); ?></h4>
        <span class="comments-date">
          <?php echo get_comment_date('d M Y'); echo ' - '; ?>
          <span class="caps"><?php echo get_comment_time(); ?></span>
        </span>
        <div class="comments-reply">
        <?php
          comment_reply_link( array_merge( $args, array(
          'reply_text' => '<span class="comment-reply-link">'. esc_html__( 'Reply', 'elate' ) .'</span>',
          'before' => '',
          'class'  => '',
          'depth' => $depth,
          'max_depth' => $args['max_depth']
          ) ) );
        ?>
        </div>
      </div>
      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'elate' ); ?></em>
      <?php endif; ?>
      <div class="comment-area">
        <?php comment_text(); ?>
      </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Title Area */
if ( ! function_exists( 'elate_title_area' ) ) {
  function elate_title_area() {

    global $post, $wp_query;
    // Get post meta in all type of WP pages
    $elate_id    = ( isset( $post ) ) ? $post->ID : 0;
    $elate_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $elate_id;
    $elate_id    = ( elate_is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $elate_id;
    $elate_meta  = get_post_meta( $elate_id, 'page_type_metabox', true );
    if ($elate_meta && (!is_archive() || elate_is_woocommerce_shop())) {
      $custom_title = $elate_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    /**
     * For strings with necessary HTML, use the following:
     * Note that I'm only including the actual allowed HTML for this specific string.
     * More info: https://codex.wordpress.org/Function_Reference/wp_kses
     */
    $allowed_title_area_tags = array(
        'a' => array(
          'href' => array(),
        ),
        'span' => array(
          'class' => array(),
        )
    );

    if( $custom_title && !is_search()) {
      echo esc_html($custom_title);
    } elseif ( is_home() ) {
      bloginfo('description');
    } elseif( is_singular('product') ) {
      $post_type = get_post_type_object( get_post_type($post) );
      echo esc_html($post_type->label);
    } elseif( is_singular('tribe_events') ) {
      echo esc_html(get_the_title($wp_query->post->ID));
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'elate' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title(esc_html__('Posts Tagged: ', 'elate'));
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'elate' ), $allowed_title_area_tags ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'elate' ), $allowed_title_area_tags ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'elate' ), $allowed_title_area_tags ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'elate' ), $allowed_title_area_tags ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( is_shop() ) {
        esc_html_e( 'Shop', 'elate' );
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        esc_html_e( 'Archives', 'elate' );
      }
    } else {
      the_title();
    }

  }
}

/**
 * Pagination Function
 */
if ( ! function_exists( 'elate_default_paging_nav' ) ) {
  function elate_default_paging_nav($nav_query = NULL) {
    if ( function_exists('wp_pagenavi')) {
      echo '<div class="eclt-pagination"><div class="eclt-pagenavi">';
      wp_pagenavi();
      echo '</div></div>';
    } else {
      global $wp_query;
      $big = 999999999;
      $current = max( 1, get_query_var('paged') );
      $total = ($nav_query != NULL) ? $nav_query->max_num_pages : $wp_query->max_num_pages;

      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo '<div class="pagination-wrap"><div class="eclt-pagination"><div class="eclt-pagenavi">';
      echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => '<i class="fa fa-angle-left"></i>',
        'next_text' => ' <i class="fa fa-angle-right"></i>',
        'current' => $current,
        'total' => $total,
        'type' => 'list'
      ));
      echo '</div></div></div>';
      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
    }
  }
}

if ( ! function_exists( 'elate_paging_nav' ) ) {
  function elate_paging_nav($numpages = '', $pagerange = '', $paged='') {

      if (empty($pagerange)) {
        $pagerange = 2;
      }
      if (empty($paged)) {
        $paged = 1;
      } else {
        $paged = $paged;
      }
      if ($numpages == '') {
        global $wp_query;
        $numpages = $wp_query->max_num_pages;
        if(!$numpages) {
          $numpages = 1;
        }
      }
      global $wp_query;
      $big = 999999999;
      if($wp_query->max_num_pages != '1' ) { ?>
      <div class="eclt-pagination">
        <?php echo paginate_links( array(
          'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
          'format' => '?paged=%#%',
          'prev_text' => '<i class="fa fa-angle-left"></i>',
          'next_text' => '<i class="fa fa-angle-right"></i>',
          'current' => $paged,
          'total' => $numpages,
          'type' => 'list'
        )); ?>
      </div>
    <?php }
  }
}

// Custom Post Type limit
function elate_custom_posts_per_page( $query ) {
  if ( post_type_exists( 'team' ) ) {
    if ( is_post_type_archive('team') ) {
      $team_limit = cs_get_option('team_limit');
      $team_limit = $team_limit ? $team_limit : '8';
      if ( $query->query_vars['post_type'] === 'team' ) $query->query_vars['posts_per_page'] = $team_limit;
    }
  }
  if ( post_type_exists( 'casestudies' ) ) {
    if ( is_post_type_archive('casestudies') ) {
      $casestudies_limit = cs_get_option('casestudies_limit');
      $casestudies_limit = $casestudies_limit ? $casestudies_limit : '6';
      if ( $query->query_vars['post_type'] === 'casestudies' ) $query->query_vars['posts_per_page'] = $casestudies_limit;
    }
    if (is_tax('casestudies_category')) {
      $casestudies_limit = cs_get_option('casestudies_limit');
      $casestudies_limit = $casestudies_limit ? $casestudies_limit : '6';
      $query->set('posts_per_page', $casestudies_limit);
    }
  }
  return $query;
}
add_filter( 'pre_get_posts', 'elate_custom_posts_per_page' );

if( ! function_exists( 'is_elementor' ) ) {
  function is_elementor(){
    $elate_page = get_post( cs_get_option('maintenance_mode_page') );
    if (Elementor\Plugin::instance()->db->is_built_with_elementor( $elate_page->ID )) {
      return true;
    } else {
      return null;
    }
  }
}