<?php
/*
 * All Theme Options for Elate theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

function elate_vt_settings( $settings ) {

  $settings           = array(
    'menu_title'      => ELATE_NAME . esc_html__(' Options', 'elate'),
    'menu_slug'       => sanitize_title(ELATE_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => ELATE_NAME .' <small>V-'. ELATE_VERSION .' by <a href="'. ELATE_BRAND_URL .'" target="_blank">'. ELATE_BRAND_NAME .'</a></small>',
  );

  return $settings;

}
add_filter( 'cs_framework_settings', 'elate_vt_settings' );

// Theme Framework Options
function elate_vt_options( $options ) {

  $options      = array(); // remove old options

  // ------------------------------
  // Theme Brand
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_brand',
    'title'    => esc_html__('Brand', 'elate'),
    'icon'     => 'fa fa-bookmark',
    'sections' => array(

      // brand logo tab
      array(
        'name'     => 'brand_logo_title',
        'title'    => esc_html__('Logo', 'elate'),
        'icon'     => 'fa fa-star',
        'fields'   => array(

          // Site Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Site Logo', 'elate')
          ),
          array(
            'id'    => 'brand_logo_default',
            'type'  => 'image',
            'title' => esc_html__('Default Logo', 'elate'),
            'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'elate'),
            'add_title' => esc_html__('Add Logo', 'elate'),
          ),
          array(
            'id'          => 'retina_width',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Width', 'elate'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'retina_height',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Height', 'elate'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_top',
            'type'        => 'number',
            'title'       => esc_html__('Logo Top Space', 'elate'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_bottom',
            'type'        => 'number',
            'title'       => esc_html__('Logo Bottom Space', 'elate'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),

          // WordPress Admin Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('WordPress Admin Logo', 'elate')
          ),
          array(
            'id'    => 'brand_logo_wp',
            'type'  => 'image',
            'title' => esc_html__('Login logo', 'elate'),
            'info'  => esc_html__('Upload your WordPress login page logo here.', 'elate'),
            'add_title' => esc_html__('Add Login Logo', 'elate'),
          ),
        ) // end: fields
      ), // end: section

      // Fav
      array(
        'name'     => 'brand_fav',
        'title'    => esc_html__('Fav Icon', 'elate'),
        'icon'     => 'fa fa-anchor',
        'fields'   => array(

            // -----------------------------
            // Begin: Fav
            // -----------------------------
            array(
              'id'    => 'brand_fav_icon',
              'type'  => 'image',
              'title' => esc_html__('Fav Icon', 'elate'),
              'info'  => esc_html__('Upload your site fav icon, size should be 16x16.', 'elate'),
              'add_title' => esc_html__('Add Fav Icon', 'elate'),
            ),
            array(
              'id'    => 'iphone_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone icon', 'elate'),
              'info'  => esc_html__('Icon for Apple iPhone (57px x 57px). This icon is used for Bookmark on Home screen.', 'elate'),
              'add_title' => esc_html__('Add iPhone Icon', 'elate'),
            ),
            array(
              'id'    => 'iphone_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone retina icon', 'elate'),
              'info'  => esc_html__('Icon for Apple iPhone retina (114px x114px). This icon is used for Bookmark on Home screen.', 'elate'),
              'add_title' => esc_html__('Add iPhone Retina Icon', 'elate'),
            ),
            array(
              'id'    => 'ipad_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad icon', 'elate'),
              'info'  => esc_html__('Icon for Apple iPad (72px x 72px). This icon is used for Bookmark on Home screen.', 'elate'),
              'add_title' => esc_html__('Add iPad Icon', 'elate'),
            ),
            array(
              'id'    => 'ipad_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad retina icon', 'elate'),
              'info'  => esc_html__('Icon for Apple iPad retina (144px x 144px). This icon is used for Bookmark on Home screen.', 'elate'),
              'add_title' => esc_html__('Add iPad Retina Icon', 'elate'),
            ),

        ) // end: fields
      ), // end: section

    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'elate'),
    'icon'   => 'fa fa-file-text'
  );

  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'elate'),
    'icon'        => 'fa fa-wrench',

    // begin: fields
    'fields'      => array(

      array(
        'id'    => 'back_to_top',
        'type'  => 'switcher',
        'title' => esc_html__('Back To Top', 'elate'),
        'info' => esc_html__('Turn Off if you want to hide back to top in your pages.', 'elate'),
        'default' => true,
      ),
      array(
        'id'    => 'theme_img_resizer',
        'type'  => 'switcher',
        'title' => esc_html__('Disable Image Resizer?', 'elate'),
        'info' => esc_html__('Turn on if you don\'t want image resizer.', 'elate'),
      ),

    ), // end: fields

  );

  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'elate'),
    'icon'     => 'fa fa-bars',
    'sections' => array(

      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'elate'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(

          // Header Select
          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'elate'),
            'options'      => array(
              'style_one'    => ELATE_CS_IMAGES .'/hs-2.png',
              'style_two'    => ELATE_CS_IMAGES .'/hs-1.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'        => true,
            'default'   => 'style_one',
            'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'elate'),
          ),
          array(
            'id'              => 'header_address_info',
            'title'           => esc_html__('Header Content', 'elate'),
            'desc'            => esc_html__('Add your header content here. Example : Address Details', 'elate'),
            'type'            => 'textarea',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          // Header Select

          // Extra's
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Extra\'s', 'elate'),
          ),
          array(
            'id'          => 'mobile_breakpoint',
            'type'        => 'text',
            'title'       => esc_html__('Mobile Menu Starts from?', 'elate'),
            'attributes'  => array( 'placeholder' => '991' ),
            'info' => esc_html__('Just put numeric value only. Like : 991. Don\'t use px or any other units.', 'elate'),
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'elate'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'search_icon',
            'type'  => 'switcher',
            'title' => esc_html__('Search Icon', 'elate'),
            'info' => esc_html__('Turn On if you want to show search icon in navigation bar.', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'cart_widget',
            'type'  => 'switcher',
            'title' => esc_html__('Cart Widget', 'elate'),
            'info' => esc_html__('Turn On if you want to show cart widget in header. Make sure about installation/activation of WooCommerce plugin.', 'elate'),
            'default' => false,
            'dependency' => array('header_design', '==', 'style_one'),
          ),

        )
      ),

      // header top bar
      array(
        'name'     => 'header_top_bar_tab',
        'title'    => esc_html__('Top Bar', 'elate'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar', 'elate'),
            'on_text'     => esc_html__('Yes', 'elate'),
            'off_text'    => esc_html__('No', 'elate'),
            'default'     => false,
          ),
          array(
            'id'          => 'top_left',
            'title'       => esc_html__('Top Left Block', 'elate'),
            'desc'        => esc_html__('Top bar left block.', 'elate'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_right',
            'title'       => esc_html__('Top Right Block', 'elate'),
            'desc'        => esc_html__('Top bar right block.', 'elate'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),

          array(
            'id'          => 'topbar_left_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Left Width in %', 'elate'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'topbar_right_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Right Width in %', 'elate'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),

        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'elate'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(

          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Title Area', 'elate')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar', 'elate'),
            'label'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'elate'),
            'default'    => true,
          ),
          array(
            'id'             => 'title_bar_padding',
            'type'           => 'select',
            'title'          => esc_html__('Padding Spaces Top & Bottom', 'elate'),
            'options'        => array(
              'padding-none' => esc_html__('Default Spacing', 'elate'),
              'padding-xs' => esc_html__('Extra Small Padding', 'elate'),
              'padding-sm' => esc_html__('Small Padding', 'elate'),
              'padding-md' => esc_html__('Medium Padding', 'elate'),
              'padding-lg' => esc_html__('Large Padding', 'elate'),
              'padding-xl' => esc_html__('Extra Large Padding', 'elate'),
              'padding-no' => esc_html__('No Padding', 'elate'),
              'padding-custom' => esc_html__('Custom Padding', 'elate'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'titlebar_top_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Top', 'elate'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),
          array(
            'id'             => 'titlebar_bottom_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Bottom', 'elate'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Background Options', 'elate'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg',
            'type'    => 'background',
            'title'   => esc_html__('Background', 'elate'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg_overlay_color',
            'type'    => 'color_picker',
            'title'   => esc_html__('Overlay Color', 'elate'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Breadcrumbs', 'elate'),
          ),
          array(
            'id'      => 'need_breadcrumbs',
            'type'    => 'switcher',
            'title'   => esc_html__('Breadcrumbs', 'elate'),
            'label'   => esc_html__('If you want Breadcrumbs in your banner, please turn this ON.', 'elate'),
            'default'    => true,
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'elate'),
    'icon'     => 'fa fa-ellipsis-h',
    'sections' => array(

      // footer widgets
      array(
        'name'     => 'footer_widgets_tab',
        'title'    => esc_html__('Widget Area', 'elate'),
        'icon'     => 'fa fa-th',
        'fields'   => array(

          // Footer Widget Block
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Footer Widget Block', 'elate')
          ),
          array(
            'id'    => 'footer_widget_block',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Widget Block', 'elate'),
            'info' => esc_html__('If you turn this ON, then Goto : Appearance > Widgets. There you can see <strong>Footer Widget 1,2,3 or 4</strong> Widget Area, add your widgets there.', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'footer_widget_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Widget Layouts', 'elate'),
            'info' => esc_html__('Choose your footer widget layouts.', 'elate'),
            'default' => 4,
            'options' => array(
              1   => ELATE_CS_IMAGES . '/footer/footer-1.png',
              2   => ELATE_CS_IMAGES . '/footer/footer-2.png',
              3   => ELATE_CS_IMAGES . '/footer/footer-3.png',
              4   => ELATE_CS_IMAGES . '/footer/footer-4.png',
              5   => ELATE_CS_IMAGES . '/footer/footer-5.png',
              6   => ELATE_CS_IMAGES . '/footer/footer-6.png',
              7   => ELATE_CS_IMAGES . '/footer/footer-7.png',
              8   => ELATE_CS_IMAGES . '/footer/footer-8.png',
              9   => ELATE_CS_IMAGES . '/footer/footer-9.png',
            ),
            'radio'       => true,
            'dependency'  => array('footer_widget_block', '==', true),
          ),

        )
      ),

      // footer copyright
      array(
        'name'     => 'footer_copyright_tab',
        'title'    => esc_html__('Copyright Bar', 'elate'),
        'icon'     => 'fa fa-copyright',
        'fields'   => array(

          // Copyright
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Copyright Layout', 'elate'),
          ),
          array(
            'id'    => 'need_copyright',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Copyright Section', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'footer_copyright_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Select Copyright Layout', 'elate'),
            'info' => esc_html__('In above image, blue box is copyright text and yellow box is secondary text.', 'elate'),
            'default'      => 'copyright-3',
            'options'      => array(
              'copyright-1'    => ELATE_CS_IMAGES .'/footer/copyright-1.png',
              'copyright-2'    => ELATE_CS_IMAGES .'/footer/copyright-2.png',
              'copyright-3'    => ELATE_CS_IMAGES .'/footer/copyright-3.png',
              ),
            'radio'        => true,
            'dependency'     => array('need_copyright', '==', true),
          ),
          array(
            'id'    => 'copyright_text',
            'type'  => 'textarea',
            'title' => esc_html__('Copyright Text', 'elate'),
            'shortcode' => true,
            'dependency' => array('need_copyright', '==', true),
            'after'       => 'Helpful shortcodes: [vt_current_year] [vt_home_url] or any shortcode.',
          ),

          // Copyright Another Text
          array(
            'type'    => 'notice',
            'class'   => 'warning cs-vt-heading',
            'content' => esc_html__('Copyright Secondary Text', 'elate'),
            'dependency'     => array('need_copyright', '==', true),
          ),
          array(
            'id'    => 'secondary_text',
            'type'  => 'textarea',
            'title' => esc_html__('Secondary Text', 'elate'),
            'shortcode' => true,
            'dependency' => array('need_copyright', '==', 'true'),
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'elate'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'elate'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'elate'),
      ),
      array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => esc_html__('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer.
          <br /><br />Highly customizable colors are in <strong>Appearance > Customize</strong>', 'elate'),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'elate'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'elate'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'elate'),
            'info'           => esc_html__('Enter css selectors like : <strong>body, .custom-class</strong>', 'elate'),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'elate'),
          ),
          array(
            'id'              => 'size',
            'type'            => 'text',
            'title'           => esc_html__('Font Size', 'elate'),
          ),
          array(
            'id'              => 'line_height',
            'type'            => 'text',
            'title'           => esc_html__('Line-Height', 'elate'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'elate'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'elate'),
        'accordion_title'     => esc_html__('New Typography', 'elate'),
        'default'             => array(
          array(
            'title'           => esc_html__('Body Typography', 'elate'),
            'selector'        => 'body, .eclt-widget .mc4wp-form input[type="email"], .eclt-widget .mc4wp-form input[type="text"]',
            'font'            => array(
              'family'        => 'Open Sans',
              'variant'       => 'regular',
            ),
            'size'            => '14px',
            'line_height'     => '1.42857143',
          ),
          array(
            'title'           => esc_html__('Menu Typography', 'elate'),
            'selector'        => '.eclt-navigation, .eclt-navigation > ul > li',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => 'regular',
            ),
            'size'            => '16px',
          ),
          array(
            'title'           => esc_html__('Sub Menu Typography', 'elate'),
            'selector'        => '.dropdown-nav > li, .dropdown-nav',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => 'regular',
            ),
            'size'            => '14px',
            'line_height'     => '1.42857143',
          ),
          array(
            'title'           => esc_html__('Headings Typography', 'elate'),
            'selector'        => 'h1, h2, h3, h4, h5, h6, .eclt-location-name',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => '600',
            ),
          ),
          array(
            'title'           => esc_html__('Shortcode Elements Primary Font', 'elate'),
            'selector'        => '.eclt-search-two input, .eclt-search-three input, .btn-fourth, .eclt-counter-two .counter-label, .eclt-list-icon h5, .eclt-testimonials-two .testi-client-info .testi-name, .eclt-testimonials-two .testi-client-info .testi-pro, .eclt-testimonials-three .testi-client-info .testi-name, .eclt-testimonials-three .testi-client-info .testi-pro, .eclt-testimonials-four .testi-client-info .testi-name, .eclt-testimonials-four .testi-client-info .testi-pro, .eclt-testimonials-five .testi-name, .eclt-list-icon h5, .eclt-comments-area .eclt-comments-meta .comments-reply, .footer-nav-links, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #review_form #respond .form-submit input, .woocommerce .products li.product a.button, .woocommerce #review_form #respond input, .woocommerce #review_form #respond select, .woocommerce #review_form #respond textarea, .woocommerce form .form-row .input-text, .woocommerce-page form .form-row .input-text, .tooltip, .elementor-widget-wrap h1, .elementor-widget-wrap h2, .elementor-widget-wrap h3, .elementor-widget-wrap h4, .elementor-widget-wrap h5',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Shortcode Elements Secondary Font', 'elate'),
            'selector'        => '.nice-select, blockquote, .eclt-link-arrow, input, select, textarea, .wpcf7 p, .eclt-title-area .page-title, .eclt-breadcrumbs ul, .eclt-topbar-left, .eclt-top-active, .eclt-recent-blog .widget-bdate, .eclt-topdd-content li a, .eclt-list-three li, .eclt-address-info, .eclt-btn, .eclt-cta-one, .eclt-cta-two, .eclt-service-one .service-heading, .eclt-service-one .services-read-more, .service-heading, .eclt-service-five .service-heading, .eclt-tab-links li a, .eclt-counter-one, .eclt-counter-two, .eclt-panel-one .panel-default > .panel-heading, .eclt-panel-two .panel-heading, .nav-tabs-two .nav-tabs > li > a, .testimonial-heading, .testi-client-info .testi-name, .eclt-testimonials-three .testi-content p, .eclt-team-member .team-content .team-name, .eclt-team-member-two .team-content .team-name, .eclt-team-member-two .team-content .view-profile, .eclt-team-details .tm-name, .eclt-history .bh-year, .eclt-blog-one .bp-top-meta > div, .eclt-blog-one .bp-heading, .eclt-blog-one .bp-read-more, .eclt-blog-one .bp-bottom-comments a, .featured-image.owl-carousel .owl-controls, .bp-share > p, .bp-author-info .author-content .author-pro, .bp-author-info .author-content .author-name, .eclt-comments-area .comments-title, .eclt-comments-area .eclt-comments-meta, .wp-pagenavi, .wp-link-pages, .eclt-list-four li, .eclt-map-address, .eclt-get-quote .bgq-btn, .eclt-widget .widget-title, .eclt-blog-widget, .eclt-sidebar .eclt-widget.eclt-recent-blog .widget-bdate, .eclt-widget .mc4wp-form input[type="submit"], .eclt-copyright, .woocommerce ul.products li.product .price, .woocommerce a.added_to_cart, .woocommerce #reviews #comments ol.commentlist li .comment-text p.meta, .woocommerce table.shop_table .cart_item td .amount, .woocommerce table.woocommerce-checkout-review-order-table tfoot td, .woocommerce ul.cart_list li a, .woocommerce ul.product_list_widget li a, .woocommerce ul.product_list_widget li .amount, .woocommerce .widget_price_filter .price_slider_amount, .woocommerce .woocommerce-result-count, .woocommerce-review-link, .woocommerce-cart .cart-collaterals .cart_totals table td, .woocommerce .widget_shopping_cart ul.product_list_widget li .amount, .woocommerce .widget_shopping_cart ul.product_list_widget li .quantity, .eclt-sidebar .eclt-widget.eclt-recent-blog .widget-btitle, .eclt-recent-blog .widget-btitle, .eclt-blog-posts a, span.elementor-button-text, h2.section-title, h3.service-heading, a.service-more, .panel-default>.panel-heading h4.panel-title a, .testi-content p, .testi-client .testi-client-info .testi-name, .testi-client .testi-client-info .testi-pro, .member-info h4, .member-info h4 a, .member-designation, .member-contact-info span a, .bp-heading, .bp-read-more, h4.widget-title, .slide-cpation-wrap h2, .slide-cpation-wrap h3, .eclt-btn, .status-item .eclt-counter, .status-item h5, .elementor-widget-wts-blog, .elementor',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Example Usage', 'elate'),
            'selector'        => '.your-custom-class',
            'font'            => array(
              'family'        => 'Nunito Sans',
              'variant'       => 'regular',
            ),
          ),
        ),
      ),

      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'elate'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'elate'),
        'class'               => 'chosen',
        'options'             => array(
          '100'   => 'Thin 100',
          '100i'  => 'Thin 100 Italic',
          '200'   => 'Extra Light 200',
          '200i'  => 'Extra Light 200 Italic',
          '300'   => 'Light 300',
          '300i'  => 'Light 300 Italic',
          '400'   => 'Regular 400',
          '400i'  => 'Regular 400 Italic',
          '500'   => 'Medium 500',
          '500i'  => 'Medium 500 Italic',
          '600'   => 'Semi Bold 600',
          '600i'  => 'Semi Bold 600 Italic',
          '700'   => 'Bold 700',
          '700i'  => 'Bold 700 Italic',
          '800'   => 'Extra Bold 800',
          '800i'  => 'Extra Bold 800 Italic',
          '900'   => 'Black 900',
          '900i'  => 'Black 900 Italic',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Font Weight',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '300', '400', '500', '600', '700', '800', '900' ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => 'Upload Custom Fonts',
        'button_title'       => 'Add New Custom Font',
        'accordion_title'    => 'Adding New Font',
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => 'Font-Family Name',
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.ttf</i>',
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.eot</i>',
            ),
          ),

          array(
            'id'             => 'svg',
            'type'           => 'upload',
            'title'          => 'Upload .svg <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.svg</i>',
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.otf</i>',
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.woff</i>',
            ),
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => 'Extra CSS Style <small><i>(optional)</i></small>',
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'elate'),
    'icon'   => 'fa fa-files-o'
  );

  // ------------------------------
  // Casestudies Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'casestudies_section',
    'title'    => esc_html__('Casestudies', 'elate'),
    'icon'     => 'fa fa-briefcase',
    'fields' => array(

      // casestudies name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'elate')
      ),
      array(
        'id'      => 'theme_casestudies_name',
        'type'    => 'text',
        'title'   => esc_html__('Casestudies Name', 'elate'),
        'attributes'     => array(
          'placeholder'  => 'Casestudies'
        ),
      ),
      array(
        'id'      => 'theme_casestudies_slug',
        'type'    => 'text',
        'title'   => esc_html__('Casestudies Slug', 'elate'),
        'attributes'     => array(
          'placeholder'  => 'casestudies-item'
        ),
      ),
      array(
        'id'      => 'theme_casestudies_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Casestudies Category Slug', 'elate'),
        'attributes'     => array(
          'placeholder'  => 'casestudies-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => esc_html__('<strong>Important</strong>: Please do not set casestudies slug and page slug as same. It\'ll not work.', 'elate')
      ),
      // Casestudies Name

      // casestudies listing
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Casestudies Style', 'elate')
      ),
      array(
        'id'             => 'casestudies_style',
        'type'           => 'select',
        'title'          => esc_html__('Casestudies Style', 'elate'),
        'options'        => array(
          'one' => esc_html__('Style One', 'elate'),
          'two' => esc_html__('Style Two', 'elate'),
        ),
        'default_option'     => esc_html__('Select Casestudies Style', 'elate'),
      ),
      array(
        'id'      => 'casestudies_limit',
        'type'    => 'text',
        'title'   => esc_html__('Case Studies Limit', 'elate'),
        'attributes'     => array(
          'placeholder'  => '10'
        ),
      ),
      array(
        'id'      => 'casestudies_show_category',
        'type'    => 'text',
        'title'   => esc_html__('Case Studies Categorys', 'elate'),
        'info'   => esc_html__('Enter category SLUGS (comma separated) you want to display.', 'elate'),
      ),
      array(
        'id'             => 'casestudies_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'elate'),
        'options'        => array(
          'none' => esc_html__('None', 'elate'),
          'ID' => esc_html__('ID', 'elate'),
          'author' => esc_html__('Author', 'elate'),
          'title' => esc_html__('Title', 'elate'),
          'date' => esc_html__('Date', 'elate'),
        ),
        'default_option'     => esc_html__('Select Case Studies Order By', 'elate'),
      ),
      array(
        'id'             => 'casestudies_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'elate'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'elate'),
          'DESC' => esc_html__('Desending', 'elate'),
        ),
        'default_option'     => esc_html__('Select Case Studies Order', 'elate'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Enable/Disable Options', 'elate')
      ),
      array(
        'id'      => 'casestudies_pagination',
        'type'    => 'switcher',
        'title'   => esc_html__('Pagination', 'elate'),
        'label'   => esc_html__('If you need pagination in casestudies pages, please turn this ON.', 'elate'),
        'default'   => true,
      ),
      array(
        'id'      => 'casestudies_filter',
        'type'    => 'switcher',
        'title'   => esc_html__('Filter', 'elate'),
        'label'   => esc_html__('If you need filter in casestudies pages, please turn this ON.', 'elate'),
        'default'   => true,
      ),
      array(
        'id'             => 'casestudies_filter_type',
        'type'           => 'select',
        'title'          => esc_html__('Filter Type', 'elate'),
        'options'        => array(
          'normal'       => esc_html__('Normal', 'elate'),
          'ajax'         => esc_html__('Ajax', 'elate'),
        ),
        'placeholder'    => esc_html__('Select Filter', 'elate'),
        'dependency'     => array('casestudies_filter', '==', 'true'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Single Casestudies', 'elate')
      ),
      array(
        'id'      => 'casestudies_single_pagination',
        'type'    => 'switcher',
        'title'   => esc_html__('Next & Prev Navigation', 'elate'),
        'label'   => esc_html__('If you don\'t want next and previous navigation in casestudies single pages, please turn this OFF.', 'elate'),
        'default'   => true,
      ),
      array(
        'id'      => 'case_studies_single_url',
        'type'    => 'text',
        'title'   => esc_html__('Navigation Section URL', 'elate'),
      ),
      // Casestudies Listing

    ),
  );

  // ------------------------------
  // Team Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'team_section',
    'title'    => esc_html__('Team', 'elate'),
    'icon'     => 'fa fa-users',
    'fields' => array(

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'elate')
      ),
      array(
        'id'            => 'theme_team_name',
        'type'          => 'text',
        'title'         => esc_html__( 'Team Name', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'Team'
        ),
      ),
      array(
        'id'            => 'theme_team_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Team Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'team-item'
        ),
      ),
      
      // Team Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Team', 'elate')
      ),
      array(
        'id'      => 'team_limit',
        'type'    => 'text',
        'title'   => esc_html__('Team Limit', 'elate'),
      ),
      array(
        'id'             => 'team_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'elate'),
        'options'        => array(
          'none' => esc_html__('None', 'elate'),
          'ID' => esc_html__('ID', 'elate'),
          'author' => esc_html__('Author', 'elate'),
          'title' => esc_html__('Title', 'elate'),
          'date' => esc_html__('Date', 'elate'),
        ),
        'default_option'     => esc_html__('Select Team Order By', 'elate'),
      ),
      array(
        'id'             => 'team_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'elate'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'elate'),
          'DESC' => esc_html__('Desending', 'elate'),
        ),
        'default_option'     => esc_html__('Select Team Order', 'elate'),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Team Single', 'elate')
      ),
      array(
        'id'      => 'team_top_spacing',
        'type'    => 'text',
        'title'   => esc_html__('Top Spacing', 'elate'),
        'info'   => esc_html__('Enter value in px, for team single pages top value.', 'elate'),
        'default' => '60px',
      ),
      array(
        'id'      => 'team_bottom_spacing',
        'type'    => 'text',
        'title'   => esc_html__('Bottom Spacing', 'elate'),
        'info'   => esc_html__('Enter value in px, for team single pages bottom value.', 'elate'),
        'default' => '0px',
      ),
      // Team End

    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'elate'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'elate'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Layout', 'elate')
          ),
          array(
            'id'             => 'blog_listing_style',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style', 'elate'),
            'options'        => array(
              'style-one' => esc_html__('List (Default)', 'elate'),
              'style-two' => esc_html__('Grid', 'elate'),
              'style-three' => esc_html__('Grid Simple', 'elate'),
            ),
            'default_option' => 'Select blog style',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author. If this settings will not apply your blog page, please set that page as a post page in Settings > Readings.', 'elate'),
          ),
          array(
            'id'             => 'blog_listing_columns',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Columns', 'elate'),
            'options'        => array(
              'col-md-12' => esc_html__('Column One', 'elate'),
              'col-md-6 col-xs-12' => esc_html__('Column Two', 'elate'),
              'col-md-4 col-sm-6 col-xs-12' => esc_html__('Column Three', 'elate'),
              'col-md-3 col-sm-6 col-xs-12' => esc_html__('Column Four', 'elate'),
            ),
            'default_option' => 'Select blog column',
            'dependency'     => array('blog_listing_style', 'any', 'style-two,style-three'),
          ),
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'elate'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'elate'),
              'sidebar-left' => esc_html__('Left', 'elate'),
              'sidebar-hide' => esc_html__('Hide', 'elate'),
            ),
            'default_option' => 'Select sidebar position',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'elate'),
            'info'          => esc_html__('Default option : Right', 'elate'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'elate'),
            'options'        => elate_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'elate'),
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'elate'),
          ),
          // Layout
          // Global Options
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Global Options', 'elate')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'elate'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'elate'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'elate'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'elate'),
            'default' => '55',
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'elate'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'elate'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'elate'),
              'date'    => esc_html__('Date', 'elate'),
              'author'     => esc_html__('Author', 'elate'),
              'comments'      => esc_html__('Comments', 'elate'),
            ),
            'std'  => 'category',
          ),
          // End fields

        )
      ),

      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'elate'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(

          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Enable / Disable', 'elate')
          ),
          array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'elate'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this OFF.', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'elate'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'elate'),
            'default' => true,
          ),
          array(
            'id'    => 'single_comment_form',
            'type'  => 'switcher',
            'title' => esc_html__('Comment Area/Form', 'elate'),
            'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this OFF.', 'elate'),
            'default' => true,
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Sidebar', 'elate')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'elate'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'elate'),
              'sidebar-left' => esc_html__('Left', 'elate'),
              'sidebar-hide' => esc_html__('Hide', 'elate'),
            ),
            'default_option' => 'Select sidebar position',
            'info'          => esc_html__('Default option : Right', 'elate'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'elate'),
            'options'        => elate_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'elate'),
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'elate'),
          ),
          // End fields

        )
      ),

    ),
  );

if (class_exists( 'WooCommerce' )){
  // ------------------------------
  // WooCommerce Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'woocommerce_section',
    'title'    => esc_html__('WooCommerce', 'elate'),
    'icon'     => 'fa fa-shopping-cart',
    'fields' => array(

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Layout', 'elate')
      ),
      array(
        'id'             => 'woo_product_columns',
        'type'           => 'select',
        'title'          => esc_html__('Product Column', 'elate'),
        'options'        => array(
          3 => esc_html__('Three Column', 'elate'),
          4 => esc_html__('Four Column', 'elate'),
        ),
        'default_option' => esc_html__('Select Product Columns', 'elate'),
        'help'          => esc_html__('This style will apply, default woocommerce listings pages. Like, shop and archive pages.', 'elate'),
      ),
      array(
        'id'             => 'woo_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'elate'),
        'options'        => array(
          'right-sidebar' => esc_html__('Right', 'elate'),
          'left-sidebar' => esc_html__('Left', 'elate'),
          'sidebar-hide' => esc_html__('Hide', 'elate'),
        ),
        'default_option' => esc_html__('Select sidebar position', 'elate'),
        'info'          => esc_html__('Default option : Right', 'elate'),
      ),
      array(
        'id'             => 'woo_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'elate'),
        'options'        => elate_vt_registered_sidebars(),
        'default_option' => esc_html__('Select Widget', 'elate'),
        'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        'info'          => esc_html__('Default option : Shop Page', 'elate'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Listing', 'elate')
      ),
      array(
        'id'      => 'theme_woo_limit',
        'type'    => 'text',
        'title'   => esc_html__('Product Limit', 'elate'),
        'info'   => esc_html__('Enter the number value for per page products limit.', 'elate'),
      ),
      array(
        'id'      => 'theme_align_height',
        'type'    => 'text',
        'title'   => esc_html__('Have Alignment Space?', 'elate'),
        'info'   => esc_html__('Set minimun height of each products here. Current minimum height is 100px', 'elate'),
      ),
      // End fields

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Single Product', 'elate')
      ),
      array(
        'id'             => 'woo_related_limit',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Limit', 'elate'),
      ),
      array(
        'id'    => 'woo_single_upsell',
        'type'  => 'switcher',
        'title' => esc_html__('You May Also Like', 'elate'),
        'info' => esc_html__('If you don\'t want \'You May Also Like\' products in single product page, please turn this ON.', 'elate'),
        'default' => false,
      ),
      array(
        'id'    => 'woo_single_related',
        'type'  => 'switcher',
        'title' => esc_html__('Related Products', 'elate'),
        'info' => esc_html__('If you don\'t want \'Related Products\' in single product page, please turn this ON.', 'elate'),
        'default' => false,
      ),
      // End fields

    ),
  );
}

  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'elate'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'elate'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'id'    => 'error_main_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'elate'),
            'info'  => esc_html__('Enter 404 page heading.', 'elate'),
          ),
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Sub Heading', 'elate'),
            'info'  => esc_html__('Enter 404 page sub heading.', 'elate'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'elate'),
            'info'  => esc_html__('Enter 404 page content.', 'elate'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'elate'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'elate'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section

      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'elate'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : <strong>Maintenance Mode Page</strong>', 'elate')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'elate'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'elate'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'elate'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'elate'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'elate'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(

      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'elate'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'elate'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'elate'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'elate'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'elate'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'elate'),
            'accordion_title' => esc_html__('New Sidebar', 'elate'),

            'default'             => array(
              array(
                'sidebar_name'   => esc_html__('Services Sidebar', 'elate'),
                'sidebar_desc'   => esc_html__('Sidebar to show widgets in services page', 'elate'),
              ),
              
            ),
          ),
          // end fields

        )
      ),
      // custom sidebar section

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'elate'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(

          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Common Texts', 'elate')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'elate'),
          ),
          array(
            'id'          => 'view_more_text',
            'type'        => 'text',
            'title'       => esc_html__('View More Text', 'elate'),
          ),
          array(
            'id'          => 'share_text',
            'type'        => 'text',
            'title'       => esc_html__('Share Text', 'elate'),
          ),
          array(
            'id'          => 'share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Share On Tooltip Text', 'elate'),
          ),
          array(
            'id'          => 'bcm_share_text',
            'type'        => 'text',
            'title'       => esc_html__('Breadcrumb Bar Share Text', 'elate'),
          ),
          array(
            'id'          => 'bcm_share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Breadcrumb Bar Share On Tooltip Text', 'elate'),
          ),
          array(
            'id'          => 'author_text',
            'type'        => 'text',
            'title'       => esc_html__('Author Text', 'elate'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'elate'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('WooCommerce', 'elate')
          ),
          array(
            'id'          => 'add_to_cart_text',
            'type'        => 'text',
            'title'       => esc_html__('Add to Cart Text', 'elate'),
          ),
          array(
            'id'          => 'details_text',
            'type'        => 'text',
            'title'       => esc_html__('Details Text', 'elate'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Pagination', 'elate')
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'elate'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'elate'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Single Casestudies Pagination', 'elate')
          ),
          array(
            'id'          => 'prev_port',
            'type'        => 'text',
            'title'       => esc_html__('Prev Project Text', 'elate'),
          ),
          array(
            'id'          => 'next_port',
            'type'        => 'text',
            'title'       => esc_html__('Next Project Text', 'elate'),
          ),
          // End Translation

        ) // end: fields
      ),

    ),
  );

  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => 'You can save your current options. Download a Backup and Import.',
      ),

      array(
        'type'    => 'backup',
      ),

    )
  );

  return $options;

}
add_filter( 'cs_framework_options', 'elate_vt_options' );